==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GeographicScatterAreaSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { GeographicXYTriangulatingSeriesDescription } from "./GeographicXYTriangulatingSeriesDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var GeographicScatterAreaSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicScatterAreaSeriesDescription, _super);
    function GeographicScatterAreaSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.dp = null;
        _this.dl = null;
        _this.dk = null;
        _this.dq = null;
        return _this;
    }
    GeographicScatterAreaSeriesDescription.prototype.get_type = function () {
        return "GeographicScatterAreaSeries";
    };
    Object.defineProperty(GeographicScatterAreaSeriesDescription.prototype, "colorMemberPath", {
        get: function () {
            return this.dp;
        },
        set: function (a) {
            this.dp = a;
            this.e("ColorMemberPath");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicScatterAreaSeriesDescription.prototype, "colorScale", {
        get: function () {
            return this.dl;
        },
        set: function (a) {
            this.dl = a;
            this.e("ColorScale");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicScatterAreaSeriesDescription.prototype, "actualColorScale", {
        get: function () {
            return this.dk;
        },
        set: function (a) {
            this.dk = a;
            this.e("ActualColorScale");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicScatterAreaSeriesDescription.prototype, "triangulationStatusChangedRef", {
        get: function () {
            return this.dq;
        },
        set: function (a) {
            this.dq = a;
            this.e("TriangulationStatusChangedRef");
        },
        enumerable: false,
        configurable: true
    });
    GeographicScatterAreaSeriesDescription.$t = markType(GeographicScatterAreaSeriesDescription, 'GeographicScatterAreaSeriesDescription', GeographicXYTriangulatingSeriesDescription.$);
    return GeographicScatterAreaSeriesDescription;
}(GeographicXYTriangulatingSeriesDescription));
export { GeographicScatterAreaSeriesDescription };

==> igniteui-react-core-19.0.0.tgz: package/esm5/lib/GeographicScatterAreaSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { GeographicXYTriangulatingSeriesDescription } from "./GeographicXYTriangulatingSeriesDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var GeographicScatterAreaSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicScatterAreaSeriesDescription, _super);
    function GeographicScatterAreaSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.fp = null;
        _this.fm = null;
        _this.fl = null;
        _this.fq = null;
        return _this;
    }
    GeographicScatterAreaSeriesDescription.prototype.get_type = function () {
        return "GeographicScatterAreaSeries";
    };
    Object.defineProperty(GeographicScatterAreaSeriesDescription.prototype, "colorMemberPath", {
        get: function () {
            return this.fp;
        },
        set: function (a) {
            this.fp = a;
            this.g("ColorMemberPath");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicScatterAreaSeriesDescription.prototype, "colorScale", {
        get: function () {
            return this.fm;
        },
        set: function (a) {
            this.fm = a;
            this.g("ColorScale");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicScatterAreaSeriesDescription.prototype, "actualColorScale", {
        get: function () {
            return this.fl;
        },
        set: function (a) {
            this.fl = a;
            this.g("ActualColorScale");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicScatterAreaSeriesDescription.prototype, "triangulationStatusChangedRef", {
        get: function () {
            return this.fq;
        },
        set: function (a) {
            this.fq = a;
            this.g("TriangulationStatusChangedRef");
        },
        enumerable: false,
        configurable: true
    });
    GeographicScatterAreaSeriesDescription.$t = markType(GeographicScatterAreaSeriesDescription, 'GeographicScatterAreaSeriesDescription', GeographicXYTriangulatingSeriesDescription.$);
    return GeographicScatterAreaSeriesDescription;
}(GeographicXYTriangulatingSeriesDescription));
export { GeographicScatterAreaSeriesDescription };
